/*
 *      Copyright (c) 2004 on behalf of the EU EGEE Project:
 *      The European Organization for Nuclear Research (CERN),
 *      Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *      Datamat Spa, Italy
 *      Centre National de la Recherche Scientifique (CNRS), France
 *      CS Systeme d'Information (CSSI), France
 *      Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *      Universiteit van Amsterdam (UvA), Netherlands
 *      University of Helsinki (UH.HIP), Finland
 *      University of Bergen (UiB), Norway
 *      Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 *
 *      ParamValue.hxx
 *
 *      Authors: Paolo Badino <paolo.badino@cern.ch>
 *      Version info: $Id: $
 *      Release: $Name:  $
 *
 *      Revision history:
 *      $Log: $
 *
 */
#ifndef GLITE_DATA_CONF_SERVICE_PARAMVALUE_HXX_
#define GLITE_DATA_CONF_SERVICE_PARAMVALUE_HXX_

#include "glite/data/config/service/ComponentConfiguration.hxx"
#include <string>

namespace glite {
namespace config{
  
/**
 * Configuration Parameters Single Value
 */
class ParamValue : public ComponentConfiguration::Param{
public:

    /**
     * ParamValue Type
     */
    static const char * TYPE;
    
    /**
     * Returns Param Type
     * @return Param Type
     */
    virtual const char * getType() const {return TYPE;}

    /**
     * Returns Param Value
     * @return Param Value
     */
    const std::string& getValue() const {return _value;}

    /**
     * Constructor
     * @param name [IN] the name of the Configuration Parameter
     * @param value [IN] the value of the Configuration Parameter
     */
    ParamValue(const char * name,const char * value):Param(name),_value(value){}

    /**
     * Destructor
     */
    virtual ~ParamValue(){}
    
private:
    /**
     * Default Constructor
     * Not Implemented
     */
    ParamValue();
    
private:
    /**
     * The Parameter SingleValue
     */
    std::string _value;        
};


} // End namespace config
} // End namespace glite

#endif //GLITE_DATA_CONF_SERVICE_PARAMVALUE_HXX_
