/*
 *      Copyright (c) 2004 on behalf of the EU EGEE Project:
 *      The European Organization for Nuclear Research (CERN),
 *      Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *      Datamat Spa, Italy
 *      Centre National de la Recherche Scientifique (CNRS), France
 *      CS Systeme d'Information (CSSI), France
 *      Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *      Universiteit van Amsterdam (UvA), Netherlands
 *      University of Helsinki (UH.HIP), Finland
 *      University of Bergen (UiB), Norway
 *      Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 *
 *      ServiceConfiguration.hxx
 *
 *      Authors: Paolo Badino <paolo.badino@cern.ch>
 *      Version info: $Id: ServiceConfiguration.hxx,v 1.1.1.1 2004/08/18 15:52:41 badino Exp $
 *      Release: $Name: glite-data-config-service_R_1_2_7 $
 *
 *      Revision history:
 *      $Log: ServiceConfiguration.hxx,v $
 *      Revision 1.1.1.1  2004/08/18 15:52:41  badino
 *      Import of Module GLite Data config Service v.0.0
 *
 *
 */
#ifndef GLITE_DATA_CONFIG_SERVICE_SERVICECONFIGURATION_HXX_
#define GLITE_DATA_CONFIG_SERVICE_SERVICECONFIGURATION_HXX_

#include "glite/data/config/service/ComponentConfiguration.hxx"
#include <pthread.h>
#include <semaphore.h>

namespace glite {
namespace config{
  
/**
 * ServiceConfiguration
 * Base class for implementing a Service Provider with a dedicated thread
 */    
class ServiceConfiguration: public ComponentConfiguration {
public:
    
    /**
     * Start the Service Thread
     * @return 0 if success
     */
    virtual int start();

    /**
     * Stop the Service
     * @return 0 if success
     */
    virtual int stop();
    
protected:

    /**
     * Constructor
     * @param name [IN] the service provider name
     */
    ServiceConfiguration(const char * name):ComponentConfiguration(name){}
    
    /**
     * Destructor
     */
    virtual ~ServiceConfiguration(){}
      
    /**
     * Service Main Method. This method should contain the service provider main
     * loop
     * @return 0 if success
     */
    virtual int svc() = 0;

    /**
     * Callback to interrupt the Service Thread. The service should provide a 
     * way to exit from the main loop 
     */
    virtual int svc_stop() = 0;
    
private:
    
    /*
     * Not Implemented
     */
    ServiceConfiguration();
    
    friend void *service_main(void * data);
    /**
     * Call the Service Main Method
     */
    void run();
    
protected:

    /**
     * Thread Identifier Property
     */
    pthread_t _tid;
    
private:    
    /*
     * Initialization Semaphore
     */
    sem_t _synch;
};

} // End namespace config
} // End namespace glite

#endif //GLITE_DATA_CONFIG_SERVICE_SERVICECONFIGURATION_HXX_
